.. highlight:: shell

============
Installation
============


Stable release
--------------

To install HDXrate, run this command in your terminal:

.. code-block:: console

    $ pip install hdxrate

Or

.. code-block:: console

    $ conda install -c conda-forge hdxrate


From sources
------------

The sources for HDXrate can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/Jhsmit/hdxrate

Or download the `tarball`_:

.. code-block:: console

    $ curl -OJL https://github.com/Jhsmit/hdxrate/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/Jhsmit/hdxrate
.. _tarball: https://github.com/Jhsmit/hdxrate/tarball/master
